<?php

/***
Copyright 2008 by Raphael Geissert <atomo64@gmail.com>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

class events
{

    function DB($db = null)
    {
        static $_db;

        if ($db === null) {
            return $_db;
        }
        $_db = $db;
    }

    function newVersion($sourcePackage, $currentVersion, $newVersion, $distribution, $downloadLink = '')
    {
        global $base, $sendNotifications;

        if (!$sendNotifications) {
            return null;
        }

        $eventsId = events::_searchEvent(__FUNCTION__, $sourcePackage, $newVersion);

        if (!empty($eventsId)) {
            echo "\nSkipping ".__FUNCTION__." event for v$newVersion of $sourcePackage; already sent";
            return null;
        }

        $tpl = file_get_contents($base . '/tpls/new_version.mail.tpl');

        $search  = array();
        $replace = array();

        $search [] = '#PACKAGE#';
        $replace[] = $sourcePackage;
        $search [] = '#DVERSION#';
        $replace[] = $currentVersion;
        $search [] = '#UVERSION#';
        $replace[] = $newVersion;
        $search [] = '#DISTRO#';
        $replace[] = $distribution;
        $search [] = '#LINK#';
        $replace[] = $downloadLink;

        $message = str_replace($search, $replace, $tpl);
        $subject = events::_extractHeader('subject', $message);
        $to      = events::_extractHeader('to', $message);
        $bcc     = events::_extractHeader('bcc', $message);

        $extraHeaders = events::_getDefaultExtraHeaders();
        $extraHeaders[] = 'X-DEHS-UVERSION: ' . $newVersion;
        $extraHeaders[] = 'BCC: ' . $bcc;

        if (!mail($to, $subject, $message, implode("\r\n", $extraHeaders), escapeshellarg($to)))
        return false;

        events::_recordEvent(__FUNCTION__, $sourcePackage, $distribution, $newVersion);
    }

    function _extractHeader($header, &$message)
    {
        $regex  = '/' . preg_quote($header, '/') . ':([ \t]*)(.*)/i';

        $matches = array();

        if (preg_match($regex, $message, $matches)) {

            $spacer = $matches[1];
            $value  = $matches[2];

            $message = trim(preg_replace($regex, '', $message));

            return $value;

        }
        return false;
    }

    function _getDefaultExtraHeaders()
    {
        global $notificationsMailFrom;
        $headers = array();

        $headers[] = 'From: ' . $notificationsMailFrom;
//        $headers[] = 'X-PTS-Approved: sure';
        $headers[] = 'X-BY-DEHS: sure';

        return $headers;
    }

    function _recordEvent($eventType, $packageName, $distribution, $content)
    {
        $db = events::DB();

        $eventType    = pg_escape_string($eventType);
        $packageName  = pg_escape_string($packageName);
        $distribution = pg_escape_string($distribution);
        $content      = pg_escape_string($content);

        pg_exec($db, "INSERT INTO events (name,type,dist,content,stamp) VALUES ('$packageName','$eventType','$distribution','$content',now())") OR die_status("Failed to record event: $packageName|$eventType|$distribution|$content");
    }

    function _searchEvent($eventType, $packageName, $contentSearch, $distribution = '', $strict = true)
    {
        $db = events::DB();

        $eventType     = pg_escape_string($eventType);
        $packageName   = pg_escape_string($packageName);
        $contentSearch = pg_escape_string($contentSearch);

        $result = pg_exec($db, "SELECT id FROM events WHERE name='$packageName' and type='$eventType' ".($distribution? "and dist='$distribution'":'')." and content ".($strict? '=' : 'LIKE')."'$contentSearch'") or die_status(pg_last_error($db)."\nFailed to SELECT id FROM events...\n");
        return pg_fetch_all($result);
    }

}

?>