#!/bin/sh
set -e

if [ ! -d "$WORKDIR" ]; then
	echo "\$WORKDIR is empty!" >&2
	exit 1
fi

cd /org/alioth.debian.org/chroot/home/groups/dehs/

PGPASSFILE="$(mktemp -p .)"
trap '[ ! -f "$PGPASSFILE" ] || rm -f "$PGPASSFILE"' EXIT
cp ./.pgpass "$PGPASSFILE"
export PGPASSFILE
cd ./htdocs/

export PGUSER=dehs
export PGHOST=localhost
export PGDATABASE=dehs

if [ "$STATS_ONLY" != "1" ]; then
    php -q $WORKDIR/www/no_watch.php > ./no_watch.html
    php -q $WORKDIR/www/no_upstream.php > ./no_upstream.html
    php -q $WORKDIR/www/no_updated.php > ./no_updated.html
    psql -A -q -c "SELECT name || ': N/A' FROM pkgs WHERE watch IS NULL OR watch=''  AND dist='unstable' ORDER BY name ASC;" | egrep -v '\?column\?|rows\)'  > ./no_watch.txt
    psql -A -q -c "SELECT name || ': Error' FROM pkgs WHERE up_version='' AND watch!='' AND dist='unstable' AND watch_warn !='' order by name asc;" | egrep -v '\?column\?|rows\)'  > ./no_upstream.real.txt
    psql -A -q -c "SELECT name || ': Error' FROM pkgs WHERE up_version='' AND watch!='' AND dist='unstable' AND watch_warn !='' AND failures_count > 2 order by name asc;" | egrep -v '\?column\?|rows\)'  > ./no_upstream.txt
    psql -A -q -c "SELECT name || ': ' || up_version FROM pkgs WHERE up_version!='' AND watch!='' AND dist='unstable' AND updated='0' AND name NOT IN (SELECT name FROM pkgs WHERE dist='experimental' AND up_version!='' AND watch!='' AND updated!='0') order by name asc;" | egrep -v '\?column\?|rows\)'  > ./no_updated.txt
    psql -A -q -c "SELECT name || ': N/A' FROM pkgs WHERE watch IS NULL OR watch=''  AND dist='unstable' UNION SELECT name || ': Error' FROM pkgs WHERE up_version='' AND watch!='' AND dist='unstable' UNION SELECT name || ': ' || up_version FROM pkgs WHERE up_version!='' AND watch!='' AND dist='unstable';" | egrep -v '\?column\?|rows\)'  > ./dehs_debianqa.txt
    psql -A -q -c "SELECT name,version,up_version,lastupvsdebsync FROM pkgs WHERE up_version!='' AND up_version IS NOT NULL AND watch!='' AND watch IS NOT NULL AND updated='0' AND dist='unstable' AND name NOT IN (SELECT name FROM pkgs WHERE dist='experimental' AND up_version!='' AND watch!='' AND updated!='0')" | egrep -v '\?column\?|rows\)' | grep -v 'name|version|up_version|lastupvsdebsync' > ./ddpomail.txt
    psql -At -q -c "SELECT COALESCE(u.name, e.name) AS source, u.up_version AS unstable_upstream, e.up_version AS experimental_upstream, u.version AS unstable_version, e.version AS experimental_version, u.dversionmangled AS unstable_parsed_version, e.dversionmangled AS experimental_parsed_version, u.updated AS unstable_uptodate, e.updated AS experimental_uptodate, u.watch_warn <> '' AS  unstable_failed, e.watch_warn <> '' AS experimental_failed, u.lastupvsdebsync AS unstable_lastsync, e.lastupvsdebsync AS experimental_lastsync FROM (select * from pkgs where dist='unstable' AND watch IS NOT NULL) AS u FULL JOIN (select * from pkgs where dist='experimental' AND watch IS NOT NULL) AS e ON u.name=e.name WHERE (u.dist='unstable' OR u.dist IS NULL) AND (e.dist='experimental' OR e.dist IS NULL);" > ./udd_dump.txt
fi

STATS=./stats.txt
cat /dev/null > $STATS.new
echo -n 'watch_count:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE watch!='';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'watch_count_unstable:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE watch!='' AND dist='unstable';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'watch_count_experimental:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE watch!='' AND dist='experimental';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'no_watch_count:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE watch IS NULL OR watch='';"  | egrep -v '[^0-9]' >> $STATS.new
echo -n 'no_watch_count_unstable:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE (watch IS NULL OR watch='') AND dist='unstable';"  | egrep -v '[^0-9]' >> $STATS.new
echo -n 'no_watch_count_experimental:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE (watch IS NULL OR watch='') AND dist='experimental';"  | egrep -v '[^0-9]' >> $STATS.new
echo -n 'watch_failed:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE up_version='' AND watch!='' AND watch_warn !='';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'watch_failed_unstable:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE up_version='' AND watch!='' AND dist='unstable' AND watch_warn !='';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'watch_failed_experimental:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE up_version='' AND watch!='' AND dist='experimental' AND watch_warn !='';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'watch_empty:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE up_version='' AND watch!='' AND (watch_warn ='' OR watch_warn IS NULL);" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'watch_empty_unstable:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE up_version='' AND watch!='' AND dist='unstable' AND (watch_warn ='' OR watch_warn IS NULL);" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'watch_empty_experimental:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE up_version='' AND watch!='' AND dist='experimental' AND (watch_warn ='' OR watch_warn IS NULL);" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'wwiz_count:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE wwiz_type='watch';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'wwiz_count_unstable:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE wwiz_type='watch' AND dist='unstable';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'wwiz_count_experimental:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE wwiz_type='watch' AND dist='experimental';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'updated_count:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE updated='1' AND up_version!='';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'updated_count_unstable:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE updated='1' AND up_version!='' AND dist='unstable';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'updated_count_experimental:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE updated='1' AND up_version!='' AND dist='experimental';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'updated_wwiz_count:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE updated='1' AND wwiz_type='watch';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'updated_wwiz_count_unstable:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE updated='1' AND dist='unstable' AND wwiz_type='watch';" | egrep -v '[^0-9]' >> $STATS.new
echo -n 'updated_wwiz_count_experimental:' >> $STATS.new
psql -A -q -c "SELECT COUNT(id) FROM pkgs WHERE updated='1' AND dist='experimental' AND wwiz_type='watch';" | egrep -v '[^0-9]' >> $STATS.new
mv $STATS.new $STATS
php -q $WORKDIR/www/stats.html > ./stats.html "$STATS"
